@@ -189,13 +189,13 @@ func RunManager() {
 	sig := signals.SetupSignalHandler()
 
 	logger.Info("Detecting ACM cluster API service...")
-	placementutils.DetectClusterRegistry(mgr.GetAPIReader(), sig)
+	placementutils.DetectClusterRegistry(sig, mgr.GetAPIReader())
 
 	// Setup webhooks
 	if !options.Debug {
 		logger.Info("setting up webhook server")
 
-		wiredWebhook, err := chWebhook.NewWireUp(mgr, sig, chWebhook.ValidateLogic)
+		wiredWebhook, err := chWebhook.NewWireUp(sig, mgr, chWebhook.ValidateLogic)
 		if err != nil {
 			logger.Error(err, "failed to initial wire up webhook")
 			os.Exit(exitCode)
