@@ -20,7 +20,7 @@ import (
 	"fmt"
 	"time"
 
-	tlog "github.com/go-logr/logr/testing"
+	"github.com/go-logr/logr"
 	. "github.com/onsi/ginkgo"
 	. "github.com/onsi/gomega"
 	v1 "k8s.io/api/core/v1"
@@ -29,9 +29,9 @@ import (
 	"k8s.io/apimachinery/pkg/types"
 	"sigs.k8s.io/controller-runtime/pkg/reconcile"
 
+	chv1 "github.com/open-cluster-management/multicloud-operators-channel/pkg/apis/apps/v1"
+	"github.com/open-cluster-management/multicloud-operators-channel/pkg/utils"
 	dplv1 "github.com/open-cluster-management/multicloud-operators-deployable/pkg/apis/apps/v1"
-	chv1 "github.com/stolostron/multicloud-operators-channel/pkg/apis/apps/v1"
-	"github.com/stolostron/multicloud-operators-channel/pkg/utils"
 )
 
 const (
@@ -84,10 +84,10 @@ var _ = Describe("object bucket controller", func() {
 			chRegistry, err := utils.CreateObjectStorageChannelDescriptor()
 			Expect(err).NotTo(HaveOccurred())
 
-			rec := newReconciler(k8sManager, chRegistry, tlog.NullLogger{})
+			rec := newReconciler(k8sManager, chRegistry, logr.DiscardLogger{})
 			recFn, result := SetupTestReconcile(rec)
 
-			Expect(add(k8sManager, recFn, tlog.NullLogger{})).NotTo(HaveOccurred())
+			Expect(add(k8sManager, recFn, logr.DiscardLogger{})).NotTo(HaveOccurred())
 
 			Expect(k8sClient.Create(ctx, dpl)).NotTo(HaveOccurred())
 
@@ -125,7 +125,7 @@ var _ = Describe("object bucket controller", func() {
 				tName:  testNamespace,
 				wantCh: nil,
 			}
-			gotCh := tC.tRec.getChannelForNamespace(testNamespace, tlog.NullLogger{})
+			gotCh := tC.tRec.getChannelForNamespace(testNamespace, logr.DiscardLogger{})
 			Expect(assertChannelObject(tC.wantCh, gotCh)).To(BeNil())
 		})
 
@@ -154,7 +154,7 @@ var _ = Describe("object bucket controller", func() {
 				Expect(tC.tRec.KubeClient.Delete(ctx, tC.dfChan)).Should(Succeed())
 			}()
 			time.Sleep(k8swait)
-			gotCh := tC.tRec.getChannelForNamespace(testNamespace, tlog.NullLogger{})
+			gotCh := tC.tRec.getChannelForNamespace(testNamespace, logr.DiscardLogger{})
 			fmt.Fprintf(GinkgoWriter, "%v", gotCh)
 			Expect(assertChannelObject(tC.wantCh, gotCh)).To(BeNil())
 		})
@@ -193,7 +193,7 @@ var _ = Describe("object bucket controller", func() {
 				Expect(tC.tRec.KubeClient.Delete(ctx, tC.dfChan)).Should(Succeed())
 			}()
 			time.Sleep(k8swait)
-			gotCh := tC.tRec.getChannelForNamespace(testNamespace, tlog.NullLogger{})
+			gotCh := tC.tRec.getChannelForNamespace(testNamespace, logr.DiscardLogger{})
 			Expect(assertChannelObject(tC.wantCh, gotCh)).To(BeNil())
 		})
 
@@ -223,7 +223,7 @@ var _ = Describe("object bucket controller", func() {
 				Expect(tC.tRec.KubeClient.Delete(ctx, tC.dfChan)).Should(Succeed())
 			}()
 			time.Sleep(k8swait)
-			gotCh := tC.tRec.getChannelForNamespace(testNamespace, tlog.NullLogger{})
+			gotCh := tC.tRec.getChannelForNamespace(testNamespace, logr.DiscardLogger{})
 			Expect(assertChannelObject(tC.wantCh, gotCh)).To(BeNil())
 		})
 	})
@@ -302,9 +302,9 @@ var _ = Describe("object bucket controller", func() {
 				},
 			}
 
-			rec := newReconciler(k8sManager, chReg, tlog.NullLogger{})
+			rec := newReconciler(k8sManager, chReg, logr.DiscardLogger{})
 
-			_, err = rec.Reconcile(req)
+			_, err = rec.Reconcile(context.TODO(), req)
 			Expect(err).Should(BeNil())
 
 			_, err = myStoreage.Get(bucket, dpl.Name)
